# Model Feature Scan Report
_Report generated on: 2025-06-16T19:49:15.100579_

## API: AnthropicApi

### API Summary
*   **Total Models Scanned:** 21
*   **Average Supported Features per Model:** 6.19

#### Feature Support Across Models:
*   Audio: 0.0% (0/21)
*   AudioConversion: 0.0% (0/21)
*   AudioEmbeddings: 4.8% (1/21)
*   AudioGeneration: 0.0% (0/21)
*   AudioTranscription: 4.8% (1/21)
*   Document: 71.4% (15/21)
*   DocumentConversion: 0.0% (0/21)
*   DocumentEmbeddings: 4.8% (1/21)
*   Image: 81.0% (17/21)
*   ImageConversion: 0.0% (0/21)
*   ImageEmbeddings: 4.8% (1/21)
*   ImageGeneration: 0.0% (0/21)
*   MCPTool: 81.0% (17/21)
*   StructuredTextGeneration: 85.7% (18/21)
*   TextEmbeddings: 4.8% (1/21)
*   TextGeneration: 81.0% (17/21)
*   Thinking: 42.9% (9/21)
*   Tools: 81.0% (17/21)
*   Video: 0.0% (0/21)
*   VideoConversion: 0.0% (0/21)
*   VideoEmbeddings: 4.8% (1/21)
*   VideoGeneration: 0.0% (0/21)
*   WebSearchTool: 66.7% (14/21)

### Model Details

#### Model: claude-2.0 (2/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-2.1 (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-3-5-haiku-20241022 (7/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-3-5-sonnet-20240620 (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-3-5-sonnet-20241022 (7/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-3-7-sonnet-20250219 (7/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-3-7-sonnet-20250219-thinking-high (8/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-3-7-sonnet-20250219-thinking-low (8/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-3-7-sonnet-20250219-thinking-mid (8/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-3-haiku-20240307 (5/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-3-opus-20240229 (5/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-opus-4-20250514 (7/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-opus-4-20250514-thinking-high (8/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-opus-4-20250514-thinking-low (8/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-opus-4-20250514-thinking-mid (7/23 features supported)
*   ❌ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-sonnet-4-20250514 (7/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-sonnet-4-20250514-thinking-high (8/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-sonnet-4-20250514-thinking-low (8/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: claude-sonnet-4-20250514-thinking-mid (8/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ✅ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: fastembed (5/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ✅ TextEmbeddings
*   ✅ ImageEmbeddings
*   ✅ AudioEmbeddings
*   ✅ VideoEmbeddings
*   ✅ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: whisper-local (1/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ✅ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

_This report is auto-generated by Litemind. Some features may not be supported due to model limitations, API restrictions, or potential bugs in Litemind._